@@ -5,6 +5,7 @@ import logging
 from asyncio import sleep
 from datetime import datetime
 from time import time
+from typing import Any, Dict, List
 
 from .const import VERSION
 from .exception_classes import LoginError
@@ -37,7 +38,7 @@ class PyXploraApi(PyXplora):
                     self._password,
                     self._userLang,
                     self._timeZone,
-                )
+                ).c()
                 if self._gqlHandler:
                     retryCounter = 0
                     while not self._isConnected() and (retryCounter < self.maxRetries + 2):
@@ -59,7 +60,7 @@ class PyXploraApi(PyXplora):
             except Exception:
                 # Login failed.
                 self._gqlHandler = None
-                self._issueToken = None
+                self._issueToken: Dict[Any, Any] = {}
         return self._issueToken
 
     async def init(self, forceLogin=False) -> None:
@@ -82,9 +83,9 @@ class PyXploraApi(PyXplora):
     ##### Contact Info #####
     async def getContacts(self, watchID) -> list:
         retryCounter = 0
-        dataOk = False
+        dataOk: List[Any] = []
         contacts_raw = None
-        contacts = []
+        contacts: List[Any] = []
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -92,11 +93,11 @@ class PyXploraApi(PyXplora):
                 contacts_raw = await self._gqlHandler.getContacts_a(watchID)
                 if "contacts" in contacts_raw:
                     if contacts_raw["contacts"] is None:
-                        dataOk = True
+                        dataOk.append({})
                         return contacts
                     if "contacts" in contacts_raw["contacts"]:
                         if not contacts_raw["contacts"]["contacts"]:
-                            dataOk = True
+                            dataOk.append({})
                             return contacts
                         for contact in contacts_raw["contacts"]["contacts"]:
                             try:
@@ -130,9 +131,9 @@ class PyXploraApi(PyXplora):
 
     async def getWatchAlarm(self, watchID) -> list:
         retryCounter = 0
-        dataOk = False
+        dataOk: List[Any] = []
         alarms_raw = None
-        alarms = []
+        alarms: List[Any] = []
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -140,7 +141,7 @@ class PyXploraApi(PyXplora):
                 alarms_raw = await self._gqlHandler.getAlarms_a(watchID)
                 if "alarms" in alarms_raw:
                     if not alarms_raw["alarms"]:
-                        dataOk = True
+                        dataOk.append({})
                         return alarms
                     for alarm in alarms_raw["alarms"]:
                         alarms.append(
@@ -166,9 +167,9 @@ class PyXploraApi(PyXplora):
 
     async def loadWatchLocation(self, watchID=0, withAsk=True) -> list:
         retryCounter = 0
-        dataOk = False
+        dataOk: List[Any] = []
         location_raw = None
-        watch_location = []
+        watch_location: List[Any] = []
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -218,10 +219,10 @@ class PyXploraApi(PyXplora):
             return True
         return False
 
-    async def getWatchOnlineStatus(self, watchID) -> WatchOnlineStatus:
+    async def getWatchOnlineStatus(self, watchID) -> str:
         retryCounter = 0
-        dataOk = False
-        asktrack_raw = None
+        dataOk = ""
+        asktrack_raw = ""
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -255,9 +256,9 @@ class PyXploraApi(PyXplora):
     async def getWatchChats(self, watchID) -> list:
         # bug?
         retryCounter = 0
-        dataOk = False
+        dataOk: List[Any] = []
         chats_raw = None
-        chats = []
+        chats: List[Any] = []
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -268,7 +269,7 @@ class PyXploraApi(PyXplora):
                 if "chats" in chats_raw:
                     if "list" in chats_raw["chats"]:
                         if not chats_raw["chats"]["list"]:
-                            dataOk = True
+                            dataOk.append({})
                             return chats
                         for chat in chats_raw["chats"]["list"]:
                             chats.append(
@@ -315,9 +316,9 @@ class PyXploraApi(PyXplora):
 
     async def getSafeZones(self, watchID) -> list:
         retryCounter = 0
-        dataOk = False
+        dataOk: List[Any] = []
         safeZones_raw = None
-        safe_zones = []
+        safe_zones: List[Any] = []
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -327,7 +328,7 @@ class PyXploraApi(PyXplora):
                 safeZones_raw = await self._gqlHandler.safeZones_a(watchID)
                 if "safeZones" in safeZones_raw:
                     if not safeZones_raw["safeZones"]:
-                        dataOk = True
+                        dataOk.append({})
                         return safe_zones
                     for safeZone in safeZones_raw["safeZones"]:
                         safe_zones.append(
@@ -361,9 +362,9 @@ class PyXploraApi(PyXplora):
     ##### Feature #####
     async def schoolSilentMode(self, watchID) -> list:
         retryCounter = 0
-        dataOk = False
+        dataOk: List[Any] = []
         silentTimes_raw = None
-        school_silent_mode = []
+        school_silent_mode: List[Any] = []
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             await self.init()
@@ -373,7 +374,7 @@ class PyXploraApi(PyXplora):
                 silentTimes_raw = await self._gqlHandler.silentTimes_a(watchID)
                 if "silentTimes" in silentTimes_raw:
                     if not silentTimes_raw["silentTimes"]:
-                        dataOk = True
+                        dataOk.append({})
                         return school_silent_mode
                     for silentTime in silentTimes_raw["silentTimes"]:
                         school_silent_mode.append(
@@ -399,7 +400,7 @@ class PyXploraApi(PyXplora):
 
     async def setEnableSilentTime(self, silentId, watchID) -> bool:
         retryCounter = 0
-        dataOk = False
+        dataOk = None
         _raw = None
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
@@ -423,7 +424,7 @@ class PyXploraApi(PyXplora):
 
     async def setDisableSilentTime(self, silentId: str, watchID) -> bool:
         retryCounter = 0
-        dataOk = False
+        dataOk = None
         _raw = None
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
@@ -459,7 +460,7 @@ class PyXploraApi(PyXplora):
 
     async def setEnableAlarmTime(self, alarmId, watchID) -> bool:
         retryCounter = 0
-        dataOk = False
+        dataOk = None
         _raw = None
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
@@ -483,7 +484,7 @@ class PyXploraApi(PyXplora):
 
     async def setDisableAlarmTime(self, alarmId, watchID) -> bool:
         retryCounter = 0
-        dataOk = False
+        dataOk = None
         _raw = None
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
